odesolv: Numerical Solution mth Order Differential Equation System

Description Usage Arguments Details Value See Also Examples

Description

The system of differential equations is linear, with possibly time-varying coefficient functions. The numerical solution is computed with the Runge-Kutta method.

Usage

1
2
3
odesolv(bwtlist, ystart=diag(rep(1,norder)),
        h0=width/100, hmin=width*1e-10, hmax=width*0.5,
        EPS=1e-4, MAXSTP=1000)

Arguments

bwtlist

a list whose members are functional parameter objects defining the weight functions for the linear differential equation.

ystart

a vector of initial values for the equations. These are the values at time 0 of the solution and its first m - 1 derivatives.

h0

a positive initial step size.

hmin

the minimum allowable step size.

hmax

the maximum allowable step size.

EPS

a convergence criterion.

MAXSTP

the maximum number of steps allowed.

Details

This function is required to compute a set of solutions of an estimated linear differential equation in order compute a fit to the data that solves the equation. Such a fit will be a linear combinations of m independent solutions.

Value

a named list of length 2 containing

tp

a vector of time values at which the system is evaluated

yp

a matrix of variable values corresponding to tp.

See Also

pda.fd,

Examples

1
#See the analyses of the lip data.

drtagkim/mcgillfdar documentation built on May 12, 2019, 6:20 p.m.