plot.pda.fd: Plot Principle Differential Analysis Components

Description Usage Arguments Details Value See Also Examples

Description

Plots the results of pda.fd, allows the user to group coefficient functions by variable, equation, derivative or combination of them.

Usage

1
2
## S3 method for class 'pda.fd'
plot(x,whichdim=1,npts=501,...)

Arguments

x

an object of class pda.fd.

whichdim

which dimension to use as grouping variables

  • 1 coefficients of each variable differential equation

  • 2 coefficient functions for each equation

  • 3 coefficients of derivatives of each variable

whichdim should be an ordered vector of length between 1 and 3.

npts

number of points to use for plotting.

...

other arguments for 'plot'.

Details

Produces one plot for each coefficient function in a principle differential analysis.

Value

invisible(NULL)

See Also

pda.fd eigen.pda

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
#  A pda analysis of the handwriting data

fdaarray = handwrit
fdatime  <- seq(0, 2.3, len=1401)

#  basis for coordinates

fdarange <- c(0, 2.3)
breaks = seq(0,2.3,length.out=501)
norder = 6
fdabasis = create.bspline.basis(fdarange,norder=norder,breaks=breaks)

#  parameter object for coordinates

fdaPar = fdPar(fdabasis,int2Lfd(4),1e-8)

#  coordinate functions and a list tontaining them

Xfd = smooth.basis(fdatime, fdaarray[,,1], fdaPar)$fd
Yfd = smooth.basis(fdatime, fdaarray[,,2], fdaPar)$fd

xfdlist = list(Xfd, Yfd)

#  basis and parameter object for weight functions

fdabasis2 = create.bspline.basis(fdarange,norder=norder,nbasis=51)
pdaPar = fdPar(fdabasis2,1,1e-8)

pdaParlist = list(pdaPar, pdaPar)

bwtlist = list( list(pdaParlist,pdaParlist), list(pdaParlist,pdaParlist) )

#  do the second order pda

pdaList = pda.fd(xfdlist, bwtlist)

# plot the results

plot(pdaList,whichdim=1)
plot(pdaList,whichdim=2)
plot(pdaList,whichdim=3)

plot(pdaList,whichdim=c(1,2))
plot(pdaList,whichdim=c(1,3))
plot(pdaList,whichdim=c(2,3))

plot(pdaList,whichdim=1:3)

drtagkim/mcgillfdar documentation built on May 12, 2019, 6:20 p.m.