Description Usage Arguments Details Value See Also Examples
Overlays the results of a univariate, second-order principal differential analysis on a bifurcation diagram to demonstrate stability.
1 | pda.overlay(pdaList,nfine=501,ncoarse=11,...)
|
pdaList |
a list object returned by |
nfine |
number of plotting points to use. |
ncoarse |
number of time markers to place along the plotted curve. |
... |
other arguments for 'plot'. |
Overlays a bivariate plot of the functional parameters in a univariate second-order principal differential analysis on a bifurcation diagram.
None.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | # This example looks at a principal differential analysis of the lip data
# in Ramsay and Silverman (2005).
# First smooth the data
lipfd <- smooth.basisPar(liptime, lip, 6, Lfdobj=int2Lfd(4),
lambda=1e-12)$fd
names(lipfd$fdnames) <- c("time(seconds)", "replications", "mm")
# Now we'll set up functional parameter objects for the beta coefficients.
lipbasis = lipfd$basis
bwtlist = list(fdPar(lipbasis,2,0.0000),fdPar(lipbasis,2,0.0000))
xfdlist <- list(lipfd)
# Call pda
pdaList <- pda.fd(xfdlist, bwtlist)
# And plot the overlay
pda.overlay(pdaList,lwd=2,cex.lab=1.5,cex.axis=1.5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.