Description Usage Arguments Value Side Effects See Also Examples
Plots all the basis functions.
1 2 |
x |
a basis object |
knots |
logical: If TRUE and x[['type']] == 'bslpine', the knot locations are plotted using vertical dotted, red lines. Ignored otherwise. |
axes |
Either a logical or a list or
|
... |
additional plotting parameters passed to |
none
a plot of the basis functions
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | ##
## 1. b-spline
##
# set up the b-spline basis for the lip data, using 23 basis functions,
# order 4 (cubic), and equally spaced knots.
# There will be 23 - 4 = 19 interior knots at 0.05, ..., 0.95
lipbasis <- create.bspline.basis(c(0,1), 23)
# plot the basis functions
plot(lipbasis)
##
## 2. Fourier basis
##
yearbasis3 <- create.fourier.basis(c(0,365),
axes=list("axesIntervals") )
# plot the basis
plot(yearbasis3)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.